import click

from .adapter import PoetryAdapter


@click.command()
@click.argument('package')
@click.argument('output', type=click.File('w'), default='pyproject.toml')
def main(package, output):
    adapter = PoetryAdapter(package)
    adapter.write(output)



from email import message_from_string

import pkg_resources

import toml


class PoetryAdapter:
    _deps = None

    def __init__(self, package):
        self._package = pkg_resources.get_distribution(package)
        raw_meta = self._package.get_metadata(self._package.PKG_INFO)
        metadata = dict(message_from_string(raw_meta))

        self._toml_dict = {
            'tool.poetry': {
                'name': metadata['Name'],
                'version': metadata['Version'],
                'description': metadata['Summary'],
                'authors': [metadata['Author']],
                'license': metadata['License']
            },
            'tool.poetry.dependencies': {
                x: y for x, y in self._iter_deps(self._dependencies)
            },
            'tool.poetry.dev-dependencies': {
                x: y for x, y in self._iter_deps(self._get_extras())
            },
            'build-system': {
                'requires': ["poetry>=0.12"],
                'build-backend': "poetry.masonry.api"
            }
        }

    def _iter_deps(self, deps):
        for dep in deps:
            try:
                yield (dep.name, "={}".format(dep.specs[0][1]))
            except IndexError:
                yield (dep.name, "*")

    def _get_extras(self):
        extra_deps = self._package.requires(self._package.extras)
        return [i for i in extra_deps if i not in self._dependencies]

    @property
    def _dependencies(self):
        if self._deps is not None:
            return self._deps

        return self._package.requires()

    def writepath(self, filepath):
        with open(filepath, "w") as f:
            self.write(f)

    def write(self, f):
        toml.dump(self._toml_dict, f)

    def print(self):
        print(toml.dumps(self._toml_dict))



# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['setup2poetry']

package_data = \
{'': ['*']}

install_requires = \
['click>=7.0,<8.0']

entry_points = \
{'console_scripts': ['setup2poetry = setup2poetry.cli:main']}

setup_kwargs = {
    'name': 'setup2poetry',
    'version': '0.1.1',
    'description': 'Tool to convert setup.py to poetry pyproject.toml',
    'long_description': None,
    'author': 'Matt Magin',
    'author_email': 'matt.magin@cmv.com.au',
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
